@@ -17,7 +17,7 @@ mod start;
 
 // (Temporary code) ESP-IDF does not (yet) have a pthread rwlock implementation, which is required by STD
 // We provide a quick and very hacky implementation here
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", esp_idf_version = "4.3"))]
 mod pthread_rwlock;
 
 // (Temporary code) ESP-IDF current stable version (4.3) has atomics for ESP32S2, but not for ESP32C3
@@ -30,10 +30,13 @@ mod atomics_esp32c3;
 ///
 /// This function will become no-op once ESP-IDF V4.4 is released
 pub fn link_patches() -> (*mut c_types::c_void, *mut c_types::c_void) {
-    #[cfg(feature = "std")]
+    #[cfg(all(feature = "std", esp_idf_version = "4.3"))]
     let rwlock = pthread_rwlock::link_patches();
 
-    #[cfg(not(feature = "std"))]
+    #[cfg(any(
+        not(feature = "std"),
+        not(all(feature = "std", esp_idf_version = "4.3"))
+    ))]
     let rwlock = core::ptr::null_mut();
 
     #[cfg(all(esp32c3, esp_idf_version = "4.3"))]
